﻿// -*- C++ -*-
// <rtc-template block="description">
/*!
 * @file  HumanProtection.cpp
 * @brief ModuleDescription
 *
 */
// </rtc-template>

#include "HumanProtection.h"

// Module specification
// <rtc-template block="module_spec">
#if RTM_MAJOR_VERSION >= 2
static const char* const humanprotection_spec[] =
#else
static const char* humanprotection_spec[] =
#endif
  {
    "implementation_id", "HumanProtection",
    "type_name",         "HumanProtection",
    "description",       "ModuleDescription",
    "version",           "2.0.0",
    "vendor",            "meijo univ.",
    "category",          "Robot",
    "activity_type",     "PERIODIC",
    "kind",              "DataFlowComponent",
    "max_instance",      "1",
    "language",          "C++",
    "lang_type",         "compile",
    // Configuration variables
    "conf.default.Judge_Parameter", "1000",

    // Widget
    "conf.__widget__.Judge_Parameter", "text",
    // Constraints

    "conf.__type__.Judge_Parameter", "float",

    ""
  };
// </rtc-template>

/*!
 * @brief constructor
 * @param manager Maneger Object
 */
HumanProtection::HumanProtection(RTC::Manager* manager)
    // <rtc-template block="initializer">
  : RTC::DataFlowComponentBase(manager),
    m_Human_PoseIn("Human_Pose", m_Human_Pose),
    m_Stop_CommandOut("Stop_Command", m_Stop_Command)
    // </rtc-template>
{
}

/*!
 * @brief destructor
 */
HumanProtection::~HumanProtection()
{
}



RTC::ReturnCode_t HumanProtection::onInitialize()
{
  // Registration: InPort/OutPort/Service
  // <rtc-template block="registration">
  // Set InPort buffers
  addInPort("Human_Pose", m_Human_PoseIn);
  
  // Set OutPort buffer
  addOutPort("Stop_Command", m_Stop_CommandOut);

  
  // Set service provider to Ports
  
  // Set service consumers to Ports
  
  // Set CORBA Service Ports
  
  // </rtc-template>

  // <rtc-template block="bind_config">
  // Bind variables and configuration variable
  bindParameter("Judge_Parameter", m_Judge_Parameter, "1000");
  // </rtc-template>

  
  return RTC::RTC_OK;
}


RTC::ReturnCode_t HumanProtection::onFinalize()
{
  return RTC::RTC_OK;
}


//RTC::ReturnCode_t HumanProtection::onStartup(RTC::UniqueId /*ec_id*/)
//{
//  return RTC::RTC_OK;
//}


//RTC::ReturnCode_t HumanProtection::onShutdown(RTC::UniqueId /*ec_id*/)
//{
//  return RTC::RTC_OK;
//}


RTC::ReturnCode_t HumanProtection::onActivated(RTC::UniqueId /*ec_id*/)
{
  return RTC::RTC_OK;
}


RTC::ReturnCode_t HumanProtection::onDeactivated(RTC::UniqueId /*ec_id*/)
{
  return RTC::RTC_OK;
}


RTC::ReturnCode_t HumanProtection::onExecute(RTC::UniqueId /*ec_id*/)
{
  std::cout << "z:= " << m_Human_Pose.pose_q.p3D.z << std::endl;

  if (m_Human_PoseIn.isNew())
  {
    m_Human_PoseIn.read();

    if (m_Human_Pose.pose_q.p3D.x == 0 && m_Human_Pose.pose_q.p3D.y == 0 && m_Human_Pose.pose_q.p3D.z == 0)
      return RTC::RTC_OK; 
    else if (m_Human_Pose.pose_q.p3D.z <= m_Judge_Parameter)
    {
      m_Stop_Command.data = 1;
      printf("stop_com=%d\r\n", m_Stop_Command.data);
    }
    else if (m_Human_Pose.pose_q.p3D.z > m_Judge_Parameter)
    {
      m_Stop_Command.data = 0;
      printf("stop_com=%d\r\n", m_Stop_Command.data);
    }
    
    m_Stop_CommandOut.write();
  }
  // else  
  // {
  //   m_Stop_Command.data = 0;
  //   printf("Init stop_com=%d\r\n", m_Stop_Command.data);
  //   m_Stop_CommandOut.write();
  // }

  return RTC::RTC_OK;
}


//RTC::ReturnCode_t HumanProtection::onAborting(RTC::UniqueId /*ec_id*/)
//{
//  return RTC::RTC_OK;
//}


//RTC::ReturnCode_t HumanProtection::onError(RTC::UniqueId /*ec_id*/)
//{
//  return RTC::RTC_OK;
//}


//RTC::ReturnCode_t HumanProtection::onReset(RTC::UniqueId /*ec_id*/)
//{
//  return RTC::RTC_OK;
//}


//RTC::ReturnCode_t HumanProtection::onStateUpdate(RTC::UniqueId /*ec_id*/)
//{
//  return RTC::RTC_OK;
//}


//RTC::ReturnCode_t HumanProtection::onRateChanged(RTC::UniqueId /*ec_id*/)
//{
//  return RTC::RTC_OK;
//}



extern "C"
{
 
  void HumanProtectionInit(RTC::Manager* manager)
  {
    coil::Properties profile(humanprotection_spec);
    manager->registerFactory(profile,
                             RTC::Create<HumanProtection>,
                             RTC::Delete<HumanProtection>);
  }
  
}
